/*
** 1998-05-25 -	Header for the DirPane formatting module.
*/

extern void		dpf_initialize(void);

extern const gchar *	dpf_get_content_name(DPContent content);
extern DPContent	dpf_get_content_from_name(const gchar *name);
extern const gchar *	dpf_get_content_mnemonic(DPContent content);
extern DPContent	dpf_get_content_from_mnemonic(const gchar *name);
extern const gchar *	dpf_get_content_title(DPContent content);

extern GtkWidget *	dpf_get_content_combo_box(GCallback func, gpointer user);

extern void		dpf_set_default_format(DpCFmt *fmt, DPContent content);
extern void		dpf_init_defaults(CfgInfo *cfg);

extern void		dpf_format_colors_row(DirPane *dp, gint row);

extern gboolean		dpf_get_content(MainInfo *min, const DirPane *dp, const DirRow2 *row, DPContent content, gchar *out, gsize max);

extern void		dpf_cell_set_style_colors(GtkCellRenderer *r, const Style *st, gboolean do_fg);

extern GtkTreeCellDataFunc	dpf_get_cell_data_func(DirPane *dp, gint column, gpointer *user);
extern void		dpf_format_colors_row2(const DirPane *dp, const DirRow2 *row, GtkCellRenderer *r, gboolean do_fg);
